@@ -8,7 +8,7 @@ SPVM::Sys::Time::Timezone - struct timezone in the C language
 
 =head1 Description
 
-The Sys::Time::Timezone class of L<SPVM> represents L<struct timezone|https://linux.die.net/man/2/gettimeofday> in the C language.
+The Sys::Time::Timezone class in L<SPVM> represents L<struct timezone|https://linux.die.net/man/2/gettimeofday> in the C language.
 
 =head1 Usage
   
@@ -36,7 +36,7 @@ Creates a new L<Sys::Time::Timezone|SPVM::Sys::Time::Timezone> object.
 
 C<method tz_minuteswest : int ();>
 
-Gets C<tz_minuteswest>.
+Returns C<tz_minuteswest>.
 
 =head2 set_tz_minuteswest
 
@@ -48,7 +48,7 @@ Sets C<tz_minuteswest>.
   
 C<method tz_dsttime : int ();>
 
-Gets C<tz_dsttime>.
+Returns C<tz_dsttime>.
 
 =head2 set_tz_dsttime
 
